==> configlinux-0.1.tar.gz: configlinux-0.1/configlinux/configchange.cpp <==
/***************************************************************************
                          configchange.cpp  -  description
                             -------------------
    begin                : Fri Jun 23 2000
    copyright            : (C) 2000 by Jae-Jun Lee
    email                : brucejr@samsung.co.kr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "configchange.h"
#include "swlioctl.h"
#include "iwcommon.h"
#include "wepdlg.h"

configChange::configChange(QWidget *parent, const char *name) : QDialog(parent,name,true){
	initDialog();
}

configChange::~configChange(){
}
/**  */
void configChange::setDialogWindows(char* name,int skfd1,int net_type,char *pssid,int channel){
   struct iwreq wrq;
   char buf[256],*bp;
   QString strTemp;
   int temp;

   bp = buf;

   strcpy(ifname,name); //adaptr name,eth0...
   skfd = skfd1;        //socket pointer.

   strcpy(wrq.ifr_name,ifname);
   //network mode
   if(net_type == 1)
    NetworkMode->setCurrentItem(1);
   else if(net_type == 3)
    NetworkMode->setCurrentItem(0);
   else
     NetworkMode->setCurrentItem(1);

   //essid
   //strTemp = strcpy(strTemp,pssid);
   SSID->setText((const char*)pssid);

  //Tx Rate.
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 1;
  wrq.u.data.flags = SWL_UIL_TXRATE_GET;
  if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while reading TX RATE...\n");
       TxRate->setCurrentItem(5);
    }
  else{
   if(buf[0] == 1)
    TxRate->setCurrentItem(0);
   else if(buf[0] == 2)
    TxRate->setCurrentItem(1);
   else if(buf[0] == 3)
    TxRate->setCurrentItem(2);
   else if(buf[0] == 4)
    TxRate->setCurrentItem(3);
   else if(buf[0] == 8)
    TxRate->setCurrentItem(4);
   else if(buf[0] == 15)
     TxRate->setCurrentItem(5);
   else
    TxRate->setCurrentItem(5);
    }

   //Domain(SWL_UIL_DOMAIN)
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 1;
  wrq.u.data.flags = SWL_UIL_DOMAIN;
  if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while reading DOMAIN...\n");
       Channel->setValue(4);
    }
  else{
   //channel
   if(buf[0] == ETSI){  //Channel 1 ~ 13
     Channel->setRange(1,13);
     Channel->setValue(4);
    }
   else if((buf[0] == FCC) || (buf[0] == IC)){ //Channel 1 ~ 11
     Channel->setRange(1,11);
     Channel->setValue(4);
     }
   else if(buf[0] == FRANCE){ //Channel 10 ~ 13
     Channel->setRange(10,13);
     Channel->setValue(10);
     }
   else if(buf[0] == SPAIN){
     Channel->setRange(10,11); //Channel 10 ~ 11
     Channel->setValue(10);
     }
   else{
     Channel->setRange(1,13);
     Channel->setValue(4);
     }
   }

   if(net_type == 1)
    Channel->setEnabled(false);

   //WEP
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 1;
  wrq.u.data.flags = SWL_UIL_WEPFLAGS_GET;
  if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while reading WEP MODE...\n");
       WEPReq->setCurrentItem(0);
    }
  else{
   if(buf[0] == 0){
    WEPReq->setCurrentItem(0);
    WEPKeyButton->setEnabled(false);
    }
   else if(buf[0] == 3){
     WEPReq->setCurrentItem(1);
     WEPKeyButton->setEnabled(true);
     }
   else{
     WEPReq->setCurrentItem(0);
     WEPKeyButton->setEnabled(false);
     }
   }
   //RTS/CTS Threshol(SWL_UIL_RTSCTS_GET)
   wrq.u.data.pointer = (caddr_t)buf;
   wrq.u.data.length = 2;
   wrq.u.data.flags = SWL_UIL_RTSCTS_GET;
   if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while reading RTS/CTS Threshold...\n");
       Threshold->setCurrentItem(0);
    }
  else{
     temp = (buf[1]<<8) + buf[0];
    if(temp== 500)
      Threshold->setCurrentItem(1);
    else if(temp ==2347)
      Threshold->setCurrentItem(0);
    else
      Threshold->setCurrentItem(1);
   }

   //PS MODE
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 1;
  wrq.u.data.flags = SWL_UIL_PSMODE_GET;
  if(ioctl(skfd,SIOCDEVPRIVATE,&wrq) < 0)
    {
       debug("There is a problem while reading PSMODE...\n");
       PSMode->setCurrentItem(0);
    }
  else{
   PSMode->setCurrentItem(buf[0]);
    }

   setCaption("Station Configuration");
   QObject::connect(OKButton,SIGNAL(clicked()),this,SLOT(OnOK()));
   QObject::connect(CancelButton,SIGNAL(clicked()),this,SLOT(reject()));
   QObject::connect(NetworkMode, SIGNAL(activated(int) ),this,SLOT(networkValueChanged(int) ) );
   QObject::connect(WEPReq, SIGNAL(activated(int) ),this,SLOT(wepreqValueChanged(int) ) );
   QObject::connect(WEPKeyButton,SIGNAL(clicked()),this,SLOT(OnWepDlg()));
}
/**  */
void configChange::OnOK(){
  struct iwreq wrq;
  char buf[256],*bp;
  const char constBuf[10],*c_bp;
  int temp,netmode_value;
  QString strTemp;

  bp = buf;
  c_bp = constBuf;
  strcpy(wrq.ifr_name, ifname);

  //set Network Mode
  netmode_value = NetworkMode->currentItem();
  if(netmode_value == 0)      //Ad-hoc
   buf[0] = 3;
  else if(netmode_value == 1) //ad-hoc
   buf[0] = 1;
  else
   buf[0] = 1;

  //debug("Network = %d\n",buf[0]);
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 1;
  wrq.u.data.flags = SWL_UIL_NETWORKMODE_SET;
  if(ioctl(skfd, SIOCDEVPRIVATE, &wrq) < 0)
    {
      debug("There is a problem while seting NETWORK MODE\n");
    }

   // set ESSID
  strTemp = SSID->text();
  strcpy(buf,strTemp);
  //debug("set ESSID=%s\n",buf);
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = strlen(buf);
  wrq.u.data.flags = 1;
  if(ioctl(skfd, SIOCSIWESSID, &wrq) < 0)
    {
       debug("There is a problem while setting ESSID\n");
    }
  //set Tx Rate.
  temp = TxRate->currentItem();
  if(temp == 0)
   buf[0] = 1;    //Fixed 1Mbps
  else if(temp == 1)
   buf[0] = 2;    //Fixed 2Mbps
  else if(temp == 2)
   buf[0] = 3;    //Auto 1 or 2
  else if(temp == 3)
   buf[0] = 4;    //Fixed 5.5Mbps
  else if(temp == 4)
   buf[0] = 8;    //Fixed 11Mbps
  else
   buf[0] = 15;   //Fully Auto.

  //debug("Tx Rate= %d\n",buf[0]);
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 1;
  wrq.u.data.flags = SWL_UIL_TXRATE_SET;
  if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while setting TX RATE...\n");
    }
  //WEP MODE
  temp = WEPReq->currentItem();
  if(temp == 0)
   buf[0] = 0;
  else if(temp == 1)
   buf[0] = 3;   //mandatory
  else
   buf[0] = 0;

  //debug("WEP= %d\n",buf[0]);
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 1;
  wrq.u.data.flags = SWL_UIL_WEPFLAGS_SET;
  if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while setting WEP...\n");
    }

  //Channel
  if(netmode_value != 3){
    c_bp= Channel->text();
    strcpy(bp,c_bp);
    temp = buf[0] - '0';
    if(buf[1] != '\0')
     temp = (temp*10) + (buf[1] - '0');

   // debug("channel =%d\n",temp);
    wrq.u.freq.m = temp;
    wrq.u.freq.e = 0;
    if(ioctl(skfd, SIOCSIWFREQ, &wrq) < 0)
   {
       debug("There is a problem while setting Channel...\n");
    }
   }

  //RS/CTS
  temp = Threshold->currentItem();
  if(temp == 0){
   buf[0] = 47;
   buf[1] = 23;
   }
  else if(temp == 1){
   buf[0] = 00;
   buf[1] = 5;
   }
  else{
   buf[0] = 47;
   buf[1] = 23;
   }

  //debug("Threshold= %d\n",wrq.u.rts.value);
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 2;
  wrq.u.data.flags = SWL_UIL_RTSCTS_SET;
  if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while setting RTS/CTS Threshold...\n");
    }
  //Power saving
   temp = PSMode->currentItem();
  if(temp == 0)
   buf[0] = 0;
  else if(temp == 1)
   buf[0] = 1;   //enable
  else
   buf[0] = 0;

  //debug("PSMODE= %d\n",buf[0]);
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 1;
  wrq.u.data.flags = SWL_UIL_PSMODE_SET;
  if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while setting PSMODE...\n");
    }

  //software reset.
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 1;
  wrq.u.data.flags = SWL_UIL_SOFTRESET;
  if(ioctl(skfd,SIOCDEVPRIVATE, &wrq) < 0)
    {
       debug("There is a problem while SOFT RESET\n");
    }

  QDialog::accept();
}
/*
void WidgetView::spinBoxValueChanged( const char * valueText )
{
QString str( "Spin box value: " );
str += valueText;
msg->setText( str );
}
*/


/**  */
void configChange::networkValueChanged(int value){
 if(value == 0)// Ad-hoc
    Channel->setEnabled(true);
 else if(value == 1)  //infrastructure
    Channel->setEnabled(false);
}
/**  */
void configChange::wepreqValueChanged(int value){
 if(value == 0) //disabled
   WEPKeyButton->setEnabled(false);
 else if(value == 1)//enabled
   WEPKeyButton->setEnabled(true);
}
/**  */
void configChange::OnWepDlg(){
  wepDlg *wepDlg_W = new wepDlg(0,"WEP Dialog");
  wepDlg_W->setGeometry(300,300,290,300);
  wepDlg_W->setDialogWindows(ifname,skfd);

  wepDlg_W->exec();
}
/**  */

==> configlinux-0.2.tar.gz: configlinux-0.2/configlinux/configchange.cpp <==
/***************************************************************************
                          configchange.cpp  -  description
                             -------------------
    begin                : Fri Jun 23 2000
    copyright            : (C) 2000 by Jae-Jun Lee
    email                : brucejr@samsung.co.kr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "configchange.h"
#include "swlioctl.h"
#include "iwcommon.h"
#include "wepdlg.h"

configChange::configChange(QWidget *parent, const char *name) : QDialog(parent,name,true){
	initDialog();
}

configChange::~configChange(){
}
/**  */
void configChange::setDialogWindows(char* name,int skfd1,int net_type,int channel){
   struct iwreq wrq;
   char buf[256],*bp;
   QString strTemp;
   int temp;
   struct wireless_info info_str,*info;

   info = &info_str;
   bp = buf;

   strcpy(ifname,name); //adaptr name,eth0...
   skfd = skfd1;        //socket pointer.

   strcpy(wrq.ifr_name,ifname);
   //network mode
   initialNetworkMode = net_type;
   if(net_type == 1)
    NetworkMode->setCurrentItem(1);
   else if(net_type == 3)
    NetworkMode->setCurrentItem(0);
   else
     NetworkMode->setCurrentItem(1);

   //essid
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 1;
  wrq.u.data.flags = SWL_UIL_ESSID;
  if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while reading ESSID...\n");
       SSID->setText("ANY");
       strcpy(initialSSID,"ANY");
    }
  else{
   if((strcmp(buf,"") ==0) || (wrq.u.data.length == 0)){
       SSID->setText("ANY");
       strcpy(initialSSID,"ANY");
      }
   else{
       SSID->setText(buf);
       strcpy(initialSSID,buf);
      }
    }

  //Tx Rate.
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 1;
  wrq.u.data.flags = SWL_UIL_TXRATE_GET;
  if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while reading TX RATE...\n");
       TxRate->setCurrentItem(5);
       initialTxRate = 0x0F;
    }
  else{
   initialTxRate = buf[0] &0xFF;
   if(buf[0] == 1)
    TxRate->setCurrentItem(0);
   else if(buf[0] == 2)
    TxRate->setCurrentItem(1);
   else if(buf[0] == 3)
    TxRate->setCurrentItem(2);
   else if(buf[0] == 4)
    TxRate->setCurrentItem(3);
   else if(buf[0] == 8)
    TxRate->setCurrentItem(4);
   else if(buf[0] == 15)
     TxRate->setCurrentItem(5);
   else
    TxRate->setCurrentItem(5);
    }

   //Domain(SWL_UIL_DOMAIN)
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 1;
  wrq.u.data.flags = SWL_UIL_DOMAIN;
  if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while reading DOMAIN...\n");
       Channel->setValue(4);
       initialChannel = 4;
    }
  else{
   //channel
   if(ioctl(skfd, SIOCGIWFREQ, &wrq) >= 0)
    {
      info->has_freq = 1;
      info->freq = wrq.u.freq.m;
      initialChannel = (int)info->freq;
    }
    else
      initialChannel = 4;

     if(buf[0] == ETSI){  //Channel 1 ~ 13
       if((initialChannel<1) || (initialChannel>13)) initialChannel = 4;
       Channel->setRange(1,13);
       Channel->setValue(initialChannel);
      }
     else if((buf[0] == FCC) || (buf[0] == IC)){ //Channel 1 ~ 11
       if((initialChannel<1) || (initialChannel>11)) initialChannel = 4;
       Channel->setRange(1,11);
       Channel->setValue(initialChannel);
      }
     else if(buf[0] == FRANCE){ //Channel 10 ~ 13
       if((initialChannel<10) || (initialChannel>13)) initialChannel = 4;
       Channel->setRange(10,13);
       Channel->setValue(initialChannel);
      }
     else if(buf[0] == SPAIN){
       if((initialChannel<10) || (initialChannel>11)) initialChannel = 4;
       Channel->setRange(10,11); //Channel 10 ~ 11
       Channel->setValue(initialChannel);
       }
     else{
       if((initialChannel<1) || (initialChannel>14)) initialChannel = 4;
       Channel->setRange(1,14);
       Channel->setValue(initialChannel);
      }
   }

   if(net_type == 1)
    Channel->setEnabled(false);

   //WEP
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 1;
  wrq.u.data.flags = SWL_UIL_WEPFLAGS_GET;
  if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while reading WEP MODE...\n");
       WEPReq->setCurrentItem(0);
       initialWepReq = 0x00;
    }
  else{
   initialWepReq = buf[0] & 0xFF;
   if(buf[0] == 0){
    WEPReq->setCurrentItem(0);
    WEPKeyButton->setEnabled(false);
    }
   else if(buf[0] == 3){
     WEPReq->setCurrentItem(1);
     WEPKeyButton->setEnabled(true);
     }
   else if(buf[0] == 7){
     WEPReq->setCurrentItem(2);
     WEPKeyButton->setEnabled(true);
     }
   else{
     WEPReq->setCurrentItem(0);
     WEPKeyButton->setEnabled(false);
     }
   }
   //RTS/CTS Threshol(SWL_UIL_RTSCTS_GET)
   wrq.u.data.pointer = (caddr_t)buf;
   wrq.u.data.length = 2;
   wrq.u.data.flags = SWL_UIL_RTSCTS_GET;
   if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while reading RTS/CTS Threshold...\n");
       Threshold->setCurrentItem(0);
       initialThreshold = 2347;
    }
  else{
    temp = (buf[1]<<8) + buf[0];
    initialThreshold = temp;
    if(temp== 500)
      Threshold->setCurrentItem(1);
    else if(temp ==2347)
      Threshold->setCurrentItem(0);
    else
      Threshold->setCurrentItem(1);
   }

   //PS MODE
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 1;
  wrq.u.data.flags = SWL_UIL_PSMODE_GET;
  if(ioctl(skfd,SIOCDEVPRIVATE,&wrq) < 0)
    {
       debug("There is a problem while reading PSMODE...\n");
       PSMode->setCurrentItem(0);
       initialPSMode = 0;
    }
  else{
   PSMode->setCurrentItem(buf[0]);
   initialPSMode = buf[0] & 0xFF;
    }

   setCaption("Station Configuration");
   QObject::connect(OKButton,SIGNAL(clicked()),this,SLOT(OnOK()));
   QObject::connect(CancelButton,SIGNAL(clicked()),this,SLOT(reject()));
   QObject::connect(NetworkMode, SIGNAL(activated(int) ),this,SLOT(networkValueChanged(int) ) );
   QObject::connect(WEPReq, SIGNAL(activated(int) ),this,SLOT(wepreqValueChanged(int) ) );
   QObject::connect(WEPKeyButton,SIGNAL(clicked()),this,SLOT(OnWepDlg()));
}
/**  */
void configChange::OnOK(){
  struct iwreq wrq;
  char buf[256],*bp;
  const char constBuf[10]={0},*c_bp;
  int temp,netmode_value;
  QString strTemp;
  bool status = false;

  bp = buf;
  c_bp = constBuf;
  strcpy(wrq.ifr_name, ifname);

  //set Network Mode
  netmode_value = NetworkMode->currentItem();
  if(netmode_value == 0)      //Ad-hoc
   buf[0] = 3;
  else if(netmode_value == 1) //infrastructure
   buf[0] = 1;
  else
   buf[0] = 1;

  if(initialNetworkMode != buf[0]&0xFF){
//    debug("Network = %d\n",buf[0]);
    status = true;
    wrq.u.data.pointer = (caddr_t)buf;
    wrq.u.data.length = 1;
    wrq.u.data.flags = SWL_UIL_NETWORKMODE_SET;
    if(ioctl(skfd, SIOCDEVPRIVATE, &wrq) < 0)
    {
      debug("There is a problem while seting NETWORK MODE\n");
    }
  }

   // set ESSID
  strTemp = SSID->text();
  strcpy(buf,strTemp);

  if(strcmp(initialSSID,strTemp) !=0){
 //    debug("set ESSID=%s\n",buf);
	  status = true;
    wrq.u.data.pointer = (caddr_t)buf;
    wrq.u.data.length = strlen(buf)+1;
    wrq.u.data.flags = 1;
    if(ioctl(skfd, SIOCSIWESSID, &wrq) < 0)
      {
         debug("There is a problem while setting ESSID\n");
     }
   }
  //set Tx Rate.
  temp = TxRate->currentItem();
  if(temp == 0)
   buf[0] = 1;    //Fixed 1Mbps
  else if(temp == 1)
   buf[0] = 2;    //Fixed 2Mbps
  else if(temp == 2)
   buf[0] = 3;    //Auto 1 or 2
  else if(temp == 3)
   buf[0] = 4;    //Fixed 5.5Mbps
  else if(temp == 4)
   buf[0] = 8;    //Fixed 11Mbps
  else
   buf[0] = 15;   //Fully Auto.

  if(initialTxRate != buf[0]& 0xFF){
//    debug("Tx Rate= %d\n",buf[0]);
    status = true;
    wrq.u.data.pointer = (caddr_t)buf;
    wrq.u.data.length = 1;
    wrq.u.data.flags = SWL_UIL_TXRATE_SET;
    if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
     {
       debug("There is a problem while setting TX RATE...\n");
     }
   }

  //WEP MODE
  temp = WEPReq->currentItem();
  if(temp == 0)
   buf[0] = 0;
  else if(temp == 1)
   buf[0] = 3;   //64 bit
  else if(temp == 2)
   buf[0] = 7;   //128 bit
  else
   buf[0] = 0;

  if(initialWepReq != buf[0]){
//    debug("WEP= %d\n",buf[0]);
    status = true;
    wrq.u.data.pointer = (caddr_t)buf;
    wrq.u.data.length = 1;
    wrq.u.data.flags = SWL_UIL_WEPFLAGS_SET;
    if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while setting WEP...\n");
     }
   }
  //Channel
  if(netmode_value != 1){
    c_bp= Channel->text();
    strcpy(bp,c_bp);
    temp = buf[0] - '0';
    if(buf[1] != '\0')
     temp = (temp*10) + (buf[1] - '0');

    if(initialChannel != temp){
//     debug("channel =%d\n",temp);
     status = true;
     wrq.u.freq.m = temp;
     wrq.u.freq.e = 0;
     if(ioctl(skfd, SIOCSIWFREQ, &wrq) < 0)
    {
       debug("There is a problem while setting Channel...\n");
     }
    }
   }

  //RS/CTS
  temp = Threshold->currentItem();
  if(temp == 0){
   buf[0] = 0x2B;
   buf[1] = 0x09;
   }
  else if(temp == 1){
   buf[0] = 0xF4;
   buf[1] = 0x01;
   }
  else{
   buf[0] = 0x2B;
   buf[1] = 0x09;
   }

  if(initialThreshold != ((buf[1]<<8) +buf[0])){
//  debug("Threshold= %x\n",(buf[1]<<8) +buf[0]);
  status = true;
  wrq.u.data.pointer = (caddr_t)buf;
  wrq.u.data.length = 2;
  wrq.u.data.flags = SWL_UIL_RTSCTS_SET;
  if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while setting RTS/CTS Threshold...\n");
    }
   }

  //Power saving
   temp = PSMode->currentItem();
  if(temp == 0)
   buf[0] = 0;
  else if(temp == 1)
   buf[0] = 1;   //enable
  else
   buf[0] = 0;

  if(initialPSMode != buf[0]){
//    debug("PSMODE= %d\n",buf[0]);
    status = true;
    wrq.u.data.pointer = (caddr_t)buf;
    wrq.u.data.length = 1;
    wrq.u.data.flags = SWL_UIL_PSMODE_SET;
    if(ioctl(skfd,SIOCDEVPRIVATE , &wrq) < 0)
    {
       debug("There is a problem while setting PSMODE...\n");
    }
   }

  //software reset.
  if(status == true){
    wrq.u.data.pointer = (caddr_t)buf;
    wrq.u.data.length = 1;
    wrq.u.data.flags = SWL_UIL_SOFTRESET;
    if(ioctl(skfd,SIOCDEVPRIVATE, &wrq) < 0)
    {
       debug("There is a problem while SOFT RESET\n");
    }
    //else
      // debug("SOFT RESET...\n");
   }
  QDialog::accept();
}
/*
void WidgetView::spinBoxValueChanged( const char * valueText )
{
QString str( "Spin box value: " );
str += valueText;
msg->setText( str );
}
*/


/**  */
void configChange::networkValueChanged(int value){
 if(value == 0)// Ad-hoc
    Channel->setEnabled(true);
 else if(value == 1)  //infrastructure
    Channel->setEnabled(false);
}
/**  */
void configChange::wepreqValueChanged(int value){
 if(value == 0) //disabled
   WEPKeyButton->setEnabled(false);
 else if((value == 1) || (value == 2))//enabled
   WEPKeyButton->setEnabled(true);
}
/**  */
void configChange::OnWepDlg(){
  int temp,temp1;

  wepDlg *wepDlg_W = new wepDlg(0,"WEP Dialog");
//  wepDlg_W->setGeometry(300,300,290,300);

  temp = WEPReq->currentItem();
  if(temp == 0)
   temp1 = 0;
  else if(temp == 1)
   temp1 = 3;   //64 bit
  else if(temp == 2)
   temp1 = 7;   //128 bit
  else
   temp1 = 0;
  wepDlg_W->setDialogWindows(ifname,skfd,temp1);

  wepDlg_W->exec();
}
/**  */
